<?php

if (!defined('ABSPATH')) {
    exit;
}

class TransactionCloudApi extends TransactionCloudHttp
{
    private const API_URL = 'https://api.transaction.cloud';
    private const SANDBOX_API_URL = 'https://sandbox-api.transaction.cloud';

    private $apiUrl;

    protected $headers;

    function __construct()
    {
        $this->initHeaders();
        $this->useSandboxEnvironment();
    }

    /**
     * @param array $headers
     */
    public function addHeader($header)
    {
        $this->headers[] = $header;
    }

    private function initHeaders()
    {
        $this->headers = array(
            'Accept: application/json',
            'Content-Type: application/json'
        );
    }

    public function useProductionEnvironment()
    {
        $this->apiUrl = self::API_URL;
    }

    public function useSandboxEnvironment()
    {
        $this->apiUrl = self::SANDBOX_API_URL;
    }

    /**
     * @param TransactionCloudCustomieProduct
     *
     * @return TransactionCloudCustomizedProduct|null
     */
    public function customizeProduct($product)
    {
        $url = $this->apiUrl . '/v1/customize-product/' . $product->getProductId();

        $data = $product->getCustomizationParams();

        try {
            $response = $this->doRequest($url, $data);

            $customizedProduct = TransactionCloudCustomizedProduct::make($response);
        } catch (\Exception $e) {
            $message = get_class($e) . ': ' . $e->getMessage();

            throw new Exception($message);
        }

        return $customizedProduct;
    }
}
