<?php

if (!defined('ABSPATH')) {
    exit;
}

class TransactionCloudPayload
{
    /**
     * @var string
     */
    private $ciphering;

    /**
     * @var string
     */
    private $key;

    private function generateIV()
    {
        return random_bytes($this->getCipherLength());
    }

    private function getCipherLength()
    {
        return openssl_cipher_iv_length(strtolower($this->ciphering));
    }

    public function setCiphering($ciphering)
    {
        $this->ciphering = $ciphering;
    }

    public function setKey($key)
    {
        $this->key = $key;
    }

    private function encrypt($iv, $string)
    {
        return openssl_encrypt(
            $string,
            $this->ciphering,
            $this->key,
            0,
            $iv
        );
    }

    private function decrypt($iv, $string)
    {
        return openssl_decrypt(
            $string,
            $this->ciphering,
            $this->key,
            0,
            $iv
        );
    }

    public function encode($value)
    {
        $iv = $this->generateIV();

        $encrypted = $this->encrypt($iv, $value);

        if (!$encrypted) {
            throw new TransactionCloudPayloadEncodeException('Could not encrypt data');
        }

        $iv = base64_encode($iv);

        $data = [
            'iv' => $iv,
            'value' => $encrypted
        ];

        $json = json_encode($data, JSON_UNESCAPED_SLASHES);

        if (json_last_error() !== JSON_ERROR_NONE) {
            throw new TransactionCloudPayloadEncodeException('Could not encode payload');
        }

        return base64_encode($json);
    }

    public function decode($string)
    {
        $payload = json_decode(base64_decode($string), true);

        if (!$this->isValid($payload)) {
            throw new TransactionCloudPayloadDecodeException('Could not decode payload');
        }

        $iv = base64_decode($payload['iv']);

        $decrypted = $this->decrypt($iv, $payload['value']);

        if (!$decrypted) {
            throw new TransactionCloudPayloadDecodeException('Could not decrypt data');
        }

        return $decrypted;
    }

    public function isValid($payload)
    {
        if (!is_array($payload)) {
            return false;
        }

        foreach (['iv', 'value'] as $item) {
            if (!isset($payload[$item]) || !is_string($payload[$item])) {
                return false;
            }
        }

        return strlen(base64_decode($payload['iv'], true)) === $this->getCipherLength();
    }
}
